
/*******************************************************************************

 Copyright (c) 2009, Charles McGarvey
 All rights reserved.
 
 Redistribution   and   use  in  source  and  binary  forms,  with  or  without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions  of  source  code  must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   * Redistributions  in binary form must reproduce the above copyright notice,
     this  list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
 
 THIS  SOFTWARE  IS  PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND  ANY  EXPRESS  OR  IMPLIED  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN  NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR  ANY  DIRECT,  INDIRECT,  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES  (INCLUDING,  BUT  NOT  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES;  LOSS  OF  USE,  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*******************************************************************************/

#include <sstream>

#include "ErrorHandler.hh"


std::string getErrorString(const Mf::Error& error)
{
	std::string str;

	switch(error.code())
	{
		case Mf::Error::ALC_INIT:
			str += "An error occurred during OpenAL initialization: ";
			str += error.what();
			return str;

		case Mf::Error::FASTEVENTS_INIT:
		case Mf::Error::SDL_INIT:
			str += "An error occurred during SDL initialization: ";
			str += error.what();
			return str;

		case Mf::Error::FILE_NOT_FOUND:
			str += "A required file (";
			str += error.what();
			str += ") could not be found.";
			return str;

		case Mf::Error::OPENAL_INIT:
			str += "The audio library returned an error: ";
			str += error.what();
			return str;

		case Mf::Error::RESOURCE_NOT_FOUND:
			str += "A required resource (";
			str += error.what();
			str += ") could not be found.";
			return str;

		case Mf::Error::SCRIPT_ERROR:
			str += "An error occurred in a script: ";
			str == error.what();
			return str;

		case Mf::Error::SDL_VIDEOMODE:
			str += "An error occurred while trying to set up the video mode.";
			return str;

		case Mf::Error::UNKNOWN_AUDIO_FORMAT:
			str += "An error occurred while trying to load an audio file, ";
			str += error.what();
			str += ".";
			return str;

		case Mf::Error::UNKNOWN_IMAGE_FORMAT:
			str += "An error occurred while trying to load an image file, ";
			str += error.what();
			str += ".";
			return str;
	}

	std::ostringstream stream;
	stream << "An unknown error (code " << error.code() << ") occurred.";
	return stream.str();
}


/** vim: set ts=4 sw=4 tw=80: *************************************************/

