
/*******************************************************************************

 Copyright (c) 2009, Charles McGarvey
 All rights reserved.
 
 Redistribution   and   use  in  source  and  binary  forms,  with  or  without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions  of  source  code  must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   * Redistributions  in binary form must reproduce the above copyright notice,
     this  list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
 
 THIS  SOFTWARE  IS  PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND  ANY  EXPRESS  OR  IMPLIED  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN  NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR  ANY  DIRECT,  INDIRECT,  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES  (INCLUDING,  BUT  NOT  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES;  LOSS  OF  USE,  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*******************************************************************************/

#ifndef _MOOF_IMAGE_HH_
#define _MOOF_IMAGE_HH_

#include <boost/shared_ptr.hpp>

#include <Moof/OpenGL.hh>
#include <Moof/Resource.hh>


namespace Mf {


class Image;
typedef boost::shared_ptr<Image> ImageP;

class Image : public Resource
{
public:

	static ImageP alloc(const std::string& name)
	{
		return ImageP(new Image(name));
	}

	explicit Image(const std::string& name);

	bool isValid() const;

	int getWidth() const;
	int getHeight() const;

	unsigned getDepth() const;
	unsigned getPitch() const;
	GLuint getMode() const;

	std::string getComment() const;

	const char* getPixels() const;
	char* getPixels();

	void flip();

	void setAsIcon() const;

	static std::string getPath(const std::string& name);

private:

	class Impl;
	boost::shared_ptr<Impl> mImpl;
};


} // namespace Mf

#endif // _MOOF_IMAGE_HH_

/** vim: set ts=4 sw=4 tw=80: *************************************************/

