
/*]  Copyright (c) 2009-2010, Charles McGarvey  [**************************
**]  All rights reserved.
*
* vi:ts=8 sw=4 tw=75
*
* Distributable under the terms and conditions of the 2-clause BSD license;
* see the file COPYING for a complete text of the license.
*
**************************************************************************/

#ifndef _MOOF_VIDEO_HH_
#define _MOOF_VIDEO_HH_

#include <string>

#include <boost/shared_ptr.hpp>

#include <SDL/SDL.h>

#include <Moof/Core.hh>


namespace Mf {


class Video;
typedef boost::shared_ptr<Video> VideoP;


class Video
{
public:

	struct Attributes
	{
		// OpenGL attributes
		long		colorBuffer[4];	// rgba
		long		frameBuffer;
		bool		doubleBuffer;
		long		depthBuffer;
		long		stencilBuffer;
		long		accumBuffer[4];	// rgba
		bool		stereo;
		long		multisampleBuffers;
		long		multisampleSamples;
		bool		swapControl;
		bool		hardwareOnly;

		// Window attributes
		std::string	caption;
		std::string	icon;
		long		mode[3];		// width, height, bpp
		bool		fullscreen;
		bool		resizable;
		bool		cursorVisible;
		bool		cursorGrab;

		Attributes();

	private:

		Backend		mBackend;

	};


	static VideoP alloc(const std::string& caption,
						const std::string& icon)
	{
		return VideoP(new Video(caption, icon));
	}

	Video();
	explicit Video(const Attributes& attribs);
	Video(const std::string& caption, const std::string& icon);
	~Video();

	void setVideoMode(const long mode[3]);
	Attributes getAttributes() const;

	void resize(int width, int height);
	bool iconify();

	void setCaption(const std::string& caption);
	std::string getCaption() const;

	const std::string& getIcon() const;

	void setFull(bool full);
	void toggleFull();
	bool isFull() const;

	void setCursorVisible(bool hasCursor);
	void toggleCursorVisible();
	bool isCursorVisible() const;

	void setResizable(bool resizable);
	void toggleResizable();
	bool isResizable() const;

	void setCursorGrab(bool cursorGrab);
	void toggleCursorGrab();
	bool isCursorGrab() const;

	void swap();

	int getWidth() const;
	int getHeight() const;

private:

	void init();

	void recreateContext();
	void setOpenGLAttributes();

	void setIcon();

	// TODO this implementation should be hidden

	SDL_Surface*	mContext;
	unsigned		mFlags;
	Attributes		mAttribs;
};


extern Video* video;


} // namespace Mf

#endif // _MOOF_VIDEO_HH_

